==> web2sms_0.1.1-4.tar.gz: web2sms-0.1.1/src/providers/createaccountdialog.hpp <==
/*
 *
 *  Copyright (c) 2010 Christoph Keller <gri@nospam@not-censored.com>
 *
 *  This file is part of Web2SMS.
 *
 *  Web2SMS is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Web2SMS is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Web2SMS. If not, see <http://www.gnu.org/licenses/>
 *
 */

#ifndef __web2sms_createaccountdialog_hpp__
#define __web2sms_createaccountdialog_hpp__

// Local includes
#include "export.hpp"
#include "providerinterface.hpp"

// Global includes
#include <QtGui/QDialog>

// Forward declarations
class CreateAccountDialogPrivate;

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

class CreateAccountDialog : public QDialog
{
  Q_OBJECT

public:
  CreateAccountDialog(QWidget* parent = 0);
  ~CreateAccountDialog();

  void setAlias(const QString& alias);
  QString alias() const;

  //void setProviderInfo(const ProviderInfo& providerInfo); // TODO: implement
  ProviderInfo providerInfo() const;

  void setProviderInfoList(const QList<ProviderInfo>& providerInfoList);
  QList<ProviderInfo> providerInfoList() const;

  // QDialog overrides
  void accept();

private:
  CreateAccountDialogPrivate* d;
};

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

#endif // __web2sms_createaccountdialog_hpp__

==> web2sms_0.1.2-0.tar.gz: web2sms-0.1.2/src/providers/createaccountdialog.hpp <==
/*
 *
 *  Copyright (c) 2010 Christoph Keller <gri@nospam@not-censored.com>
 *
 *  This file is part of Web2SMS.
 *
 *  Web2SMS is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Web2SMS is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Web2SMS. If not, see <http://www.gnu.org/licenses/>
 *
 */

#ifndef __web2sms_createaccountdialog_hpp__
#define __web2sms_createaccountdialog_hpp__

// Local includes
#include "providerinfo.hpp"

// Global includes
#include <QtGui/QDialog>

// Forward declarations
class CreateAccountDialogPrivate;

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

class CreateAccountDialog : public QDialog
{
  Q_OBJECT

public:
  CreateAccountDialog(QWidget* parent = 0);
  ~CreateAccountDialog();

  void setAlias(const QString& alias);
  QString alias() const;

  //void setProviderInfo(const ProviderInfo& providerInfo); // TODO: implement
  ProviderInfo providerInfo() const;

  void setProviderInfoList(const QList<ProviderInfo>& providerInfoList);
  QList<ProviderInfo> providerInfoList() const;

  // QDialog overrides
  void accept();

private:
  CreateAccountDialogPrivate* d;
};

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

#endif // __web2sms_createaccountdialog_hpp__
